@@ -10,16 +10,24 @@
 // necessary, as all additional functionality should be defined in the
 // parser's class header.
 
-void Generator::baseclassHeader() const
+void Generator::baseClassHeader() const
 {
-    if (d_arg.option(0, "no-baseclass-header"))
+    if (
+        d_arg.option(0, "no-baseclass-header")
+        ||
+        (
+            d_arg.option(0, "dont-rewrite-baseclass-header") 
+            &&
+            Stat(d_options.baseClassHeader())
+        )
+    )
         return;
 
     ofstream out;
     ifstream in;
 
-    Errno::open(in,  d_parser.baseclassSkeleton()); 
-    Errno::open(out, d_parser.baseclassHeader()); 
+    Errno::open(in,  d_options.baseClassSkeleton()); 
+    Errno::open(out, d_options.baseClassHeader()); 
 
     filter(in, out);    
 }
