@@ -10,17 +10,17 @@ void Generator::classHeader() const
 {
     if 
     (
-        access(d_parser.classHeader().c_str(), F_OK) == 0
-        &&
         not d_arg.option(0, "force-class-header")
+        &&
+        Stat(d_options.classHeader())
     )
         return;
 
     ofstream out;
     ifstream in;
 
-    Errno::open(in,  d_parser.classSkeleton()); 
-    Errno::open(out, d_parser.classHeader()); 
+    Errno::open(in,  d_options.classSkeleton()); 
+    Errno::open(out, d_options.classHeader()); 
 
     filter(in, out);    
 }
