@@ -37,7 +37,4 @@ Generator::Map Generator::s_insert =
 char const *Generator::s_baseFlag = "\\@";
 size_t const Generator::s_baseFlagSize = 2; // backslash and @
 
-string Generator::s_matchedTextFunction = "d_scanner.YYText()";
-string Generator::s_scannerTokenFunction = "d_scanner.yylex()";
-
 
