@@ -13,17 +13,17 @@ void Generator::implementationHeader() const
 {
     if 
     (
-        access(d_parser.implementationHeader().c_str(), F_OK) == 0
-        &&
         not d_arg.option(0, "force-implementation-header")
+        &&
+        Stat(d_options.implementationHeader())
     )
         return;
 
     ofstream out;
     ifstream in;
 
-    Errno::open(in,  d_parser.implementationSkeleton()); 
-    Errno::open(out, d_parser.implementationHeader()); 
+    Errno::open(in,  d_options.implementationSkeleton()); 
+    Errno::open(out, d_options.implementationHeader()); 
 
     filter(in, out);    
 }
