@@ -2,9 +2,9 @@
 
 void Generator::preIncludes(std::ostream &out) const
 {
-    if (d_parser.preInclude().empty())
+    if (d_options.preInclude().empty())
         return;
 
     key(out);
-    out <<  "#include " << d_parser.preInclude() << '\n';
+    out <<  "#include " << d_options.preInclude() << '\n';
 }
