@@ -1,13 +1,9 @@
 #include "parser.ih"
 
-char Parser::s_defaultClassName[]         = "Parser";
-char Parser::s_defaultParsefunSource[]  = "parse.cc";
-
 size_t Parser::s_nHidden;
 
 ostringstream Parser::s_hiddenName;
 
-
 char Parser::s_semanticValue[] = "d_val__";   
                                     // name of the semantic value variable
                                     // used by the generated parser.
@@ -17,3 +13,8 @@ char Parser::s_semanticValueStack[] = "d_vsp__";
 char Parser::s_locationValueStack[] = "d_lsp__";  
                                     // name of the location value stack
                                     // used by the generated parser
+
+
+
+
+
