@@ -15,13 +15,13 @@ bool Parser::explicitElement(size_t pos, int nElements, Block &block)
     size_t ruleElements = nComponents(nElements);
 
     if (!d_unionDeclared)               // no %union: no explicit types
-        lineMsg(wmsg) << "No %union declaration: can't resolve $<" << 
+        wmsg << "No %union declaration: can't resolve $<" << 
             explicitType << ">" << idx << " for element $" << idx << 
             " in `" << d_rules.name()  << endl;
 
                                         // $i refers beyond this rule
     else if (idx > static_cast<int>(ruleElements))
-        lineMsg(emsg) << "In  " << d_rules.name() << 
+        emsg << "In  " << d_rules.name() << 
                 ": $<" << explicitType << ">" << idx << 
                 " used, but the rule has only " << 
                 ruleElements << " elements" << endl;
@@ -38,7 +38,7 @@ bool Parser::explicitElement(size_t pos, int nElements, Block &block)
             || 
             !d_negativeDollarIndices    // or don't accept indices <= 0
         )                             
-            lineMsg(wmsg) << "Using $<" << explicitType << ">" << idx << 
+            wmsg << "Using $<" << explicitType << ">" << idx << 
                 " for "<< (idx <= 0 ? "type-indeterminable" : "") <<
                 " element $" << idx << " in `" << 
                 d_rules.name() << "'" << endl;
