@@ -1,6 +1,6 @@
 #include "parser.ih"
 
-void Parser::handleProductionElement(PTag *last)
+void Parser::handleProductionElement(spSemBase const &last)
 {
         // maybe also when currentRule == 0 ? See addProduction
     if (!d_rules.hasRules())    // may happen if the first rule could not be
@@ -12,29 +12,21 @@ void Parser::handleProductionElement(PTag *last)
         return;
     }
 
-    switch (last->tag)
+    switch (last->tag())
     {
-        case PTag::TERMINAL:
-            d_rules.addElement(last->terminal);
+        case Tag::TERMINAL:
+            d_rules.addElement(last->as<Tag::TERMINAL>());
             checkFirstType();
         break;
-        case PTag::SYMBOL:
-            d_rules.addElement(last->symbol);
+        case Tag::SYMBOL:
+            d_rules.addElement(last->as<Tag::SYMBOL>());
             checkFirstType();
         break;
-        case PTag::BLOCK:
-            installAction(last->block);
+        case Tag::BLOCK:
+            installAction(last->as<Tag::BLOCK>());
         break;
-        case PTag::NONE:    // can't occur, but used to keep the 
+
+        default:            // can't occur, but used to keep the 
         break;              // compiler from generating a warning
     }
-
-    delete last;
 }
-
-
-
-
-
-
-
